@@ -59,7 +59,9 @@
 #include "qgraphicsanchorlayout.h"
 #include "qgraph_p.h"
 #include "qsimplex_p.h"
-#ifndef QT_NO_GRAPHICSVIEW
+
+QT_REQUIRE_CONFIG(graphicsview);
+
 QT_BEGIN_NAMESPACE
 
 /*
@@ -71,6 +73,7 @@ QT_BEGIN_NAMESPACE
   respectively.
 */
 
+namespace QtGraphicsAnchorLayout {
 /*!
   \internal
 
@@ -196,7 +199,7 @@ struct SequentialAnchorData : public AnchorData
 #endif
     }
 
-    virtual void updateChildrenSizes() Q_DECL_OVERRIDE;
+    virtual void updateChildrenSizes() override;
     void calculateSizeHints();
 
     QVector<AnchorVertex*> m_children;          // list of vertices in the sequence
@@ -224,7 +227,7 @@ struct ParallelAnchorData : public AnchorData
 #endif
     }
 
-    virtual void updateChildrenSizes() Q_DECL_OVERRIDE;
+    virtual void updateChildrenSizes() override;
     bool calculateSizeHints();
 
     bool secondForward() const {
@@ -260,7 +263,7 @@ inline QString AnchorVertex::toString() const
 {
     if (m_type == Pair) {
         const AnchorVertexPair *vp = static_cast<const AnchorVertexPair *>(this);
-        return QString::fromLatin1("(%1, %2)").arg(vp->m_first->toString()).arg(vp->m_second->toString());
+        return QString::fromLatin1("(%1, %2)").arg(vp->m_first->toString(), vp->m_second->toString());
     } else if (!m_item) {
         return QString::fromLatin1("NULL_%1").arg(quintptr(this));
     }
@@ -324,6 +327,9 @@ public:
     QSet<AnchorData *> positives;
     QSet<AnchorData *> negatives;
 };
+} // namespace QtGraphicsAnchorLayout
+using namespace QtGraphicsAnchorLayout;
+
 Q_DECLARE_TYPEINFO(GraphPath, Q_MOVABLE_TYPE);
 
 class QGraphicsAnchorLayoutPrivate;
@@ -344,6 +350,9 @@ public:
 
     void setSizePolicy(QSizePolicy::Policy policy);
 
+    static QGraphicsAnchorPrivate *get(QGraphicsAnchor *q)
+    { return q->d_func(); }
+
     QGraphicsAnchorLayoutPrivate *layoutPrivate;
     AnchorData *data;
 
@@ -591,6 +600,5 @@ public:
 };
 
 QT_END_NAMESPACE
-#endif //QT_NO_GRAPHICSVIEW
 
 #endif
